@@ -75,6 +75,20 @@ class Fs_core_config_class extends Safe_configurable_object_class
                 'The log level to use when logging SIP traces (SIP messages logged) for SIP profiles with tracing enabled.',
                 'If a log level is used that is below the core log level, the SIP messages will not be logged even when the SIP profiles have tracing enabled.')
             );
+
+        $this->add_enum_field('enable-session-log-dumping', 'Enable Session Log Dumping', 'dropdown', 'false', $this->enable_disable_enum());
+        $this->set_field_help('enable-session-log-dumping', array('When maximum log level is lower or equal to WARNING, ',
+                                                                  'this option allows to enable ability to dump all previous ',
+																  'debug traces when a WARNING, ERROR, CRITICAL or ALERT event occurs.',
+                                                                  '<span class="field_error">Enable this option will increase memory usage and reduce performance.</span>'));
+        $this->create_group('session-log-dumping-options',array('session-log-dump-queue-size'));
+        $this->conditional_control('enable-session-log-dumping', 'session-log-dumping-options');
+        $this->add_field('session-log-dump-queue-size', 'Session Log Dump Queue Size','int', 100);
+        $this->set_field_help('session-log-dump-queue-size', array('Maximum number of logging entries ',
+                                                                   'to keep in memory when session log',
+                                                                   ' dumping is enabled.'));
+
+
         return parent::configure();
     }
     /**
@@ -224,6 +238,8 @@ class Fs_core_module_class extends Fs_module_class
                 'max_sessions' => $data['max-sessions'],
                 'sps' => $data['sessions-per-second'],
                 'loglevel' => $data['loglevel'],
+                'enable_session_log_dumping' => $data['enable-session-log-dumping'],
+                'session_log_dump_queue_size' => $data['session-log-dump-queue-size']
             );
             // Loop to apply new parameters value
             foreach ($reload_param as $k => $v) {
