@@ -520,7 +520,9 @@ class Fs_distributor_module_class extends Fs_module_class
         // Default implementation - Check object name exists (but check in 
         // merged list)
         $objs = $this->lists();
-        if($objs[$name]){
+        //Add case-insensitive object name validation
+        $obj_keys = array_keys($objs);
+        if(safe_in_arrayi($name, $obj_keys)){
             $reason = "Already exists";
             return false;
         }
