@@ -99,7 +99,7 @@ class Fs_sip_profile_class extends Safe_configurable_object_class
       ) );
     $this->set_field_help('transport','Transport type being used for SIP.');
 
-    $this->add_field('outbound-proxy', 'Outbound Proxy', 'string', '');
+    $this->add_field('outbound-proxy', 'Outbound Proxy', 'string', '', 50);
     $this->set_field_rules('outbound-proxy', 'valid_ip_port_domain');
     $this->set_field_help('outbound-proxy', 'Optional outbound proxy');
 
@@ -189,6 +189,8 @@ class Fs_sip_profile_class extends Safe_configurable_object_class
 		    array('false' => 'Disable', 'proxy' => 'Enable')
 		    );
     $this->set_field_help('enable-3pcc','Enable processing of 3PCC (third party call control) to allow processing INVITE messages without an SDP');
+    $this->add_enum_field('enable-request-dns-caching', 'Request SIP DNS Caching', 'dropdown', 'false', $this->enable_disable_enum());
+    $this->set_field_help('enable-request-dns-caching','Enable SIP DNS caching. Cached value will be used on subsequent outgoing SIP Request with the same URL');
     $this->add_enum_field('ignore-183nosdp', 'Ignore 183 without SDP', 'dropdown', 'false', $this->enable_disable_enum());
     $this->set_field_help('ignore-183nosdp','Enable or Disable ignoring 183 messages without a specific SDP.');
 
@@ -280,7 +282,15 @@ class Fs_sip_profile_class extends Safe_configurable_object_class
     $this->set_field_help('srtp/require-secure-rtp','Require inbound leg INVITE to include secure rtp offer.');
 
     $this->add_enum_field('srtp/support-sdp-secure-avp','Secure AVP','dropdown','false',$this->enable_disable_enum());
-    $this->set_field_help('srtp/support-sdp-secure-avp', array('Enable or disable SDP secure AVP (a=crypto in RTP/AVP).','','Note: This option violates RFC 3711.'));
+    $this->set_field_help('srtp/support-sdp-secure-avp', array(
+			    'This option breaks RFC 3711 and is only valid when Lync Interoperability is enabled.',
+			    '',
+			    'When this option is enabled, SDP media lines will use RTP/AVP even when SRTP is enabled',
+			    'and an a=crypto line will be added as usual for SRTP sessions.',
+			    '',
+			    'The standard RTP/SAVP profile will not be used for SDP secure media lines when this option is enabled.',
+			    ''
+                         ));
 
     $this->add_enum_field('srtp/crypto-optional-lifetime','Crypto Life Time','dropdown','__disable__',array(
       '__disable__' => 'Disable',
