@@ -73,7 +73,7 @@ class Nsc_domain_class extends Fs_domain_class
         $this->set_field_help('registrar-profile', 'This SIP profile will be used to contact the registrar server and forward the REGISTER message');
         $this->add_field('registrar-server', 'Forward Registrar Server', 'string', '', 50);
         $this->set_field_rules('registrar-server', 'required[forward-registration]');
-        $this->set_field_help('registrar-server', 'Registration server IP address or Domain Name.');
+        $this->set_field_help('registrar-server', 'Registration server IP address or host name.');
         $this->add_field('registrar-port', 'Forward Registrar Server Port', 'string', '5060', 10);
         $this->set_field_rules('registrar-port', 'required[forward-registration]|valid_port_number');
         $this->set_field_help('registrar-port', 'Registration servers IP Port.');
