@@ -85,12 +85,12 @@ class Nsc_media_profile_class extends Fs_media_profile_class
             'G729@30i' => 'G.729 30ms, PT=18',
             'iLBC@15200b@20i' => 'iLBC 15.20Kbps 20ms, PT=98',
             'iLBC@13330b@30i' => 'iLBC 13.33Kbps 30ms, PT=97',
-            'GSM@20i' => 'GSM, PT=3',
+            'GSM@20i' => 'GSM 20ms, PT=3',
             'G722@20i' => 'G.722 20ms, PT=9',
             'G722@30i' => 'G.722 30ms, PT=9',
             'G7221@16000h@32000b@20i' => 'G.722.1 32Kbps 20ms, PT=107',
             'G7221@16000h@24000b@20i' => 'G.722.1 24Kbps 20ms, PT=107',
-            'G723@30i' => 'G.723.1 30ms, PT=4',
+            'G723@30i' => 'G.723.1 6.3Kbps 30ms, PT=4',
             'G726-16@20i' => 'G.726 16Kbps 20ms, PT=124',
             'G726-24@20i' => 'G.726 24Kbps 20ms, PT=123',
             'G726-32@20i' => 'G.726 32Kbps 20ms, PT=122',
