@@ -217,6 +217,15 @@ class Nsc_sip_profile_class extends Fs_sip_profile_class
         $this->set_field_help('lync-interop','Enable or disable settings for Lync interoperability.');
         $this->add_enum_field('allow-malformed-headers', 'Allow Malformed Headers', 'dropdown', 'false', $this->enable_disable_enum());
         $this->set_field_help('allow-malformed-headers','Allow receiving malformed non-critical SIP headers available in dialplan via <b>sip_mh_[header_name]</b> channel variable.');
+        $this->add_enum_field('strict-sdp-parsing', 'Strict SDP Parsing', 'dropdown', 'false', $this->enable_disable_enum());
+        $this->set_field_help('strict-sdp-parsing',
+            array('Enable strict SDP parsing',
+                  '',
+                  'When this option is enabled, the SDP contents will be strictly checked for compliance with',
+                  'RFC 4566 and any SDP contents in SIP messages that do not conform will be rejected.',
+                  'For interoperability with broken equipment it\'s sometimes desirable to relax the parser to',
+                  'tolerate minor deviations from the RFC. In such cases you can disable this option.'
+                 ));
     }
     protected function configure_authentication()
     {
