@@ -427,7 +427,7 @@ class CI_Input
         // Clean $_POST Data
         if (is_array($_POST) AND count($_POST) > 0) {
             foreach ($_POST as $key => $val) {
-                $_POST[$this->_clean_input_keys($key) ] = $this->_clean_input_data($val);
+                $_POST[$this->_clean_input_keys($key) ] = $this->_clean_input_data($val, TRUE);
             }
         }
         // Clean $_COOKIE Data
@@ -464,12 +464,12 @@ class CI_Input
      * @param	string
      * @return	string
      */
-    function _clean_input_data($str)
+    function _clean_input_data($str, $from_post=FALSE)
     {
         if (is_array($str)) {
             $new_array = array();
             foreach ($str as $key => $val) {
-                $new_array[$this->_clean_input_keys($key) ] = $this->_clean_input_data($val);
+                $new_array[$this->_clean_input_keys($key) ] = $this->_clean_input_data($val, $from_post);
             }
             return $new_array;
         }
@@ -485,8 +485,28 @@ class CI_Input
         if (UTF8_ENABLED === TRUE) {
             $str = $this->uni->clean_string($str);
         }
+        $_urlencoded = TRUE;
         // Remove control characters
-        $str = remove_invisible_characters($str);
+        if($from_post){
+          // Check content type
+          $_dummy = $this->get_request_header('Content-Type');
+          // Locate content-type header - sometimes not always with same case, 
+          // so loop around and compare lower case
+          foreach($this->request_headers() as $k => $v){
+            if('content-type' == strtolower($k)){
+              // Any urlencoded in content-type ?
+              if(FALSE == strpos($v, "urlencoded")){
+                // No so it's not urlencoded
+                $_urlencoded = FALSE;
+              }
+              break;
+            }
+          }
+        }
+
+        // Remove invisble char and pass urlencoded boolean
+        $str = remove_invisible_characters($str, $_urlencoded);
+
         // Should we filter the input data?
         if ($this->_enable_xss === TRUE) {
             $str = $this->security->xss_clean($str);
