@@ -1545,6 +1545,52 @@ class CI_Form_validation {
       }
       return false;
 
+  }
+  /*
+   * SIP SecMon specific validation rules
+  */
+  function validate_account_filter($str)
+  {
+      // Rules are:
+      // 1/ Empty string
+      // 2/ 'unknown' string
+      // 3/ comma separated account list (email)
+      // 4/ 'regex=xxxxx' string
+      $rc = (bool)FALSE;
+      $str = trim($str);
+      if ('' == $str || 'unknown' == strtolower($str) || !strncmp($str, 'regex=', strlen('regex='))) {
+          return (bool)TRUE;
+      } else {
+          // Coma separeted account list
+          // default is all good :)
+          $rc = (bool)TRUE;
+          $account_list = explode(',', $str);
+          foreach ($account_list as $account) {
+              // check for exclamation mark
+              $account = trim($account);
+              if ($account) {
+                  if (!strncmp($account, '!', 1)) $account = substr($account, 1);
+                  if (false == ($this->valid_sip_account($account) || preg_match('/@.+/', $account))) {
+                      $rc = (bool)false;
+                      break;
+                  }
+              }
+          }
+      }
+      return $rc;
+  }
+  
+  function validate_user_agent_filter($str)
+  {
+      // Rules are:
+      // 1/ Empty string
+      // 3/ Full string
+      // 4/ 'regex=xxxxx' string
+      $str = trim($str);
+      if ('' == $str || $str || !strncmp($str, 'regex=', strlen('regex='))) {
+          return (bool)TRUE;
+      }
+      return (bool)FALSE;
   }
 	// --------------------------------------------------------------------
   /**
