@@ -259,34 +259,32 @@ class Sng_notifier_service_class extends Safe_service_class
     }
     public function get_action_settings()
     {
-        $email_cfg = $this->config()->email_config();
-        $_app = $this->node()->software()->application();
-        if($email_cfg)
-        {
-            //check if smtp is enabled
-            $smtp_test_param =  new Safe_configurable_object_class('autofill', 'smtp_test_param');
-            $smtp_test_param->add_field('email', 'Email Address', 'text', '','50');
-            $smtp_test_param->set_field_rules('email','required|valid_email');
-            $data = array(
-                    'test' => array(
-                            'name' => 'Test',
-                            'description' => 'Notifier test',
-                            'request' => 'POST',
-                            'param' => $smtp_test_param
-                           )
-            );
-            return $data;
-        }else{
-            return null;
-        }
+        $smtp_test_param =  new Safe_configurable_object_class('autofill', 'smtp_test_param');
+        $smtp_test_param->add_field('email', 'Email Address', 'text', '','50');
+        $smtp_test_param->set_field_rules('email','required|valid_email');
+        $data = array(
+                'test' => array(
+                        'name' => 'Test Notification',
+                        'icon' => 'bell',
+                        'description' => 'Notifier test',
+                        'request' => 'POST',
+                        'param' => $smtp_test_param
+                )
+        );
+        return $data;
     }
     public function api_test_action($data=null, &$output = null) {
-        $action_settings = $this->get_action_settings();
-        $action_cfg = $action_settings['test'];
-        $param = $action_cfg['param'];
-        if ($param->validate($data, $output)) {
-            $rs =  $this->test($data, $output);
-            return $rs;
+        $email_cfg = $this->config()->email_config();
+        if($email_cfg){
+            $action_settings = $this->get_action_settings();
+            $action_cfg = $action_settings['test'];
+            $param = $action_cfg['param'];
+            if ($param->validate($data, $output)) {
+                $rs =  $this->test($data, $output);
+                return $rs;
+            }
+        }else{
+            $output['message'] = 'Email Notification is disabled.';
         }
         return false;
     }
@@ -616,7 +614,7 @@ class Sng_notifier_service_class extends Safe_service_class
                     $output['reason'] = $email_lib->get_error();
                 }
             }else{
-                $output['reason'] = 'Email address is required';
+                $output['reason'] = 'Email Notification is disabled.';
             }
         }
         if($output['reason'] != ''){
