@@ -281,7 +281,7 @@ class Sng_config_manager extends Safe_CI_Controller
         $table_heading_array = array();
         $table = new Safe_crud_table_class();
         $table->set_controller_url($this->router->fetch_class());
-        $data['table_id'] = $_id.'_'.$_type;
+        $data['table_id'] = str_replace('.', '_', $_id.'_'.$_type);
         if($obj_type && $obj_name){
             $base_url = $base_url . '/' . $obj_type.'/' . $obj_name;
         }
@@ -360,7 +360,7 @@ class Sng_config_manager extends Safe_CI_Controller
             $table = new Safe_crud_table_class();
             $data['table_size'] = '100%';
             $data['table_title'] = $table->set_title(ucwords($description));
-            $data['table_id'] = $_id;
+            $data['table_id'] = str_replace('.', '_', $_id);
             $table->set_controller_url($this->router->fetch_class());
             if($obj_type && $obj_name){
                 $table->primary_key = $module_name.'/'.$obj_type.'/'.$obj_name;
@@ -427,7 +427,7 @@ class Sng_config_manager extends Safe_CI_Controller
                 $data['table_size'] = '100%';
                 $data['table_container_class'] = 'safe_datatable';
                 $data['table_title'] = $table->set_title($_definition['name']);
-                $data['table_id'] = $_id.'_'.$_type;
+                $data['table_id'] = str_replace('.', '_', $_id.'_'.$_type);
                 $table->set_controller_url($this->router->fetch_class());
 
                 $table_heading_array = array();
