@@ -1923,9 +1923,16 @@ class Firewall extends Daemon
 	}
 
 	/**
-	 * @ignore
+	 * Check if firewall is running
+	 *
+	 * @return boolean true if firewall is running
 	 */
 
+	public function IsRunning()
+	{
+			return file_exists("/var/run/nsc.firewall.running");
+	}
+
 	public function __destruct()
 	{
 		if (COMMON_DEBUG_MODE)
