@@ -80,6 +80,10 @@ $webconfig = new Webconfig();
 if (!isset($_SESSION['system_session_started']))
 	WebSetSession();
 
+if (!empty($_SESSION['user_login'])) {
+	session_write_close();
+}
+
 // Pull in global locale
 require_once(GlobalGetLanguageTemplate(COMMON_CORE_DIR . '/api/Locale.class.php'));
 
@@ -1029,6 +1033,14 @@ function WebUrlJump($url, $description)
  */
 
 function WebAuthenticate()
+{
+	session_start();
+	$ret = _WebAuthenticate($redirect);
+	session_write_close();
+	return $ret;
+}
+
+function _WebAuthenticate($redirect=true)
 {
 	// Logout requested
 	//-----------------
@@ -1566,133 +1578,138 @@ function WebForwardPage($page)
 
 function WebMenuFetch()
 {
-	global $webconfig;
+  if(empty($_SESSION['pagedata'])){
+    global $webconfig;
 
-	$pageinfo = array();
-	$pagedata = array();
-	$pagelist = array();
-	$pageorder = array();
-	$rawdata = array();
+    $pageinfo = array();
+    $pagedata = array();
+    $pagelist = array();
+    $pageorder = array();
+    $rawdata = array();
 
-	// Grab language code
-	//-------------------
+    // Grab language code
+    //-------------------
 
-	if (isset($_SESSION['system_locale']))
-		$langcode = $_SESSION['system_locale'];
-	else
-		$langcode = "en_US";
+    if (isset($_SESSION['system_locale']))
+      $langcode = $_SESSION['system_locale'];
+    else
+      $langcode = "en_US";
 
-	// Grab list of valid pages for given user
-	//----------------------------------------
+    // Grab list of valid pages for given user
+    //----------------------------------------
 
-	$validpages = array();
+    $validpages = array();
 
-	if (isset($_SESSION['user_login'])) {
-		try {
-			if (isset($_SESSION['system_valid_pages_regular']) && isset($_SESSION['system_valid_pages_admin'])) {
-				$validregular = explode("|", $_SESSION['system_valid_pages_regular']);
-				$validadmin = explode("|", $_SESSION['system_valid_pages_admin']);
-				$validpages = array_merge($validregular, $validadmin);
-			} else {
-				$validpageinfo = $webconfig->GetValidPages($_SESSION['user_login']);
-				$validpages = array_merge($validpageinfo[Webconfig::TYPE_USER_REGULAR], $validpageinfo[Webconfig::TYPE_USER_ADMIN]);
-			}
-		} catch (Exception $e) {
-			// Do nothing
-		}
-	}
+    if (isset($_SESSION['user_login'])) {
+      try {
+        if (isset($_SESSION['system_valid_pages_regular']) && isset($_SESSION['system_valid_pages_admin'])) {
+          $validregular = explode("|", $_SESSION['system_valid_pages_regular']);
+          $validadmin = explode("|", $_SESSION['system_valid_pages_admin']);
+          $validpages = array_merge($validregular, $validadmin);
+        } else {
+          $validpageinfo = $webconfig->GetValidPages($_SESSION['user_login']);
+          $validpages = array_merge($validpageinfo[Webconfig::TYPE_USER_REGULAR], $validpageinfo[Webconfig::TYPE_USER_ADMIN]);
+        }
+      } catch (Exception $e) {
+        // Do nothing
+      }
+    }
 
-	// Go through the menu directory to build menu system
-	//---------------------------------------------------
+    // Go through the menu directory to build menu system
+    //---------------------------------------------------
 
-	$filelist = array();
-	$files = array();
-	$menudir = WEBCONFIG_PATH . "/menus";
+    $filelist = array();
+    $files = array();
+    $menudir = WEBCONFIG_PATH . "/menus";
 
-	$dir = dir($menudir);
+    $dir = dir($menudir);
 
-	while (($file = $dir->read())) {
-		$parts = explode(".", $file);
+    while (($file = $dir->read())) {
+      $parts = explode(".", $file);
 
-		if (isset($parts[1]) && ($parts[1] == "en_US"))
-			$defaultlist[$parts[0]] = "en_US";
-		else if (isset($parts[1]) && ($parts[1] == $langcode)) {
-			$localelist[$parts[0]] = $langcode;
-		}
-	}
+      if (isset($parts[1]) && ($parts[1] == "en_US"))
+        $defaultlist[$parts[0]] = "en_US";
+      else if (isset($parts[1]) && ($parts[1] == $langcode)) {
+        $localelist[$parts[0]] = $langcode;
+      }
+    }
 
-	$dir->close();
+    $dir->close();
 
-	foreach ($defaultlist as $key => $value) {
-		if (isset($localelist[$key]))
-			$files[] = $key . "." . $langcode;
-		else
-			$files[] = $key . ".en_US";
-	}
+    foreach ($defaultlist as $key => $value) {
+      if (isset($localelist[$key]))
+        $files[] = $key . "." . $langcode;
+      else
+        $files[] = $key . ".en_US";
+    }
 
-	// Put our menu information into handy arrays.  The arrays are built
-	// to be generic enough to be used in any kind of menu system.
-	//------------------------------------------------------------------
+    // Put our menu information into handy arrays.  The arrays are built
+    // to be generic enough to be used in any kind of menu system.
+    //------------------------------------------------------------------
 
-	$inx = 1;
+    $inx = 1;
 
-	foreach ($files as $file) {
-		if (!($fh_t = @fopen($menudir . "/" . $file, "r")))
-			continue;
+    foreach ($files as $file) {
+      if (!($fh_t = @fopen($menudir . "/" . $file, "r")))
+        continue;
 
-		while (!feof($fh_t)) {
-			$line = chop(fgets($fh_t, 4096));
+      while (!feof($fh_t)) {
+        $line = chop(fgets($fh_t, 4096));
 
-			if (empty($line))
-				continue;
+        if (empty($line))
+          continue;
 
-			$entry = explode("|", $line);
+        $entry = explode("|", $line);
 
-			if (sizeof($entry) < 4)
-				continue;
+        if (sizeof($entry) < 4)
+          continue;
 
-			// If no path is specified, assume /admin/
-			//---------------------------------------
+        // If no path is specified, assume /admin/
+        //---------------------------------------
 
-			if (!preg_match("/\//", $entry[3]))
-				$entry[3] = "/admin/$entry[3]";
+        if (!preg_match("/\//", $entry[3]))
+          $entry[3] = "/admin/$entry[3]";
 
-			// Continue if this is not a valid page for given user
-			//----------------------------------------------------
+        // Continue if this is not a valid page for given user
+        //----------------------------------------------------
 
-			if (empty($_SESSION['system_login']) && (! (in_array($entry[3], $validpages))))
-				continue;
+        if (empty($_SESSION['system_login']) && (! (in_array($entry[3], $validpages))))
+          continue;
 
-			// Continue if this is only a user page and not intended for root login
-			//---------------------------------------------------------------------
-			// KLUDGE / TODO: maybe these pages should be put in /public or /user?
+        // Continue if this is only a user page and not intended for root login
+        //---------------------------------------------------------------------
+        // KLUDGE / TODO: maybe these pages should be put in /public or /user?
 
-			if (isset($_SESSION['user_login']) && ($_SESSION['user_login'] == "root")) {
-				if ($entry[3] == "/admin/security.php")
-					continue;
-			}
+        if (isset($_SESSION['user_login']) && ($_SESSION['user_login'] == "root")) {
+          if ($entry[3] == "/admin/security.php")
+            continue;
+        }
 
-			$pageinfo["section"] = $entry[0];
-			$pageinfo["subsection"] = $entry[1];
-			$pageinfo["title"] = $entry[2];
-			$pageinfo["url"] = $entry[3];
-			$pageinfo["type"] = $entry[4];
-			$pageinfo["priority"] = empty($entry[5]) ? '99999' : $entry[5];
+        $pageinfo["section"] = $entry[0];
+        $pageinfo["subsection"] = $entry[1];
+        $pageinfo["title"] = $entry[2];
+        $pageinfo["url"] = $entry[3];
+        $pageinfo["type"] = $entry[4];
+        $pageinfo["priority"] = empty($entry[5]) ? '99999' : $entry[5];
 
-			$pageorder[$pageinfo["priority"] . "." . $pageinfo["subsection"] . "." . $pageinfo["title"]] = $pageinfo['url'];
+        $pageorder[$pageinfo["priority"] . "." . $pageinfo["subsection"] . "." . $pageinfo["title"]] = $pageinfo['url'];
 
-			$rawdata[$pageinfo["url"]] = $pageinfo;
-		}
+        $rawdata[$pageinfo["url"]] = $pageinfo;
+      }
 
-		fclose($fh_t);
-	}
+      fclose($fh_t);
+    }
 
-	ksort($pageorder);
+    ksort($pageorder);
 
-	foreach ($pageorder as $key => $url)
-		$pagedata[] = $rawdata[$url];
+    foreach ($pageorder as $key => $url)
+      $pagedata[] = $rawdata[$url];
 
-	return $pagedata;
+    session_start();
+    $_SESSION['pagedata'] = $pagedata;
+    session_write_close();
+  }
+  return $_SESSION['pagedata'];
 }
 
 ///////////////////////////////////////////////////////////////////////////////
